import os
import vot
from vot import Rectangle
import sys
import cv2
import numpy as np
import random
try:
    del os.environ['MKL_NUM_THREADS']
    import torch
except:
    import torch
def setup_seed(seed):
    torch.manual_seed(seed)
    torch.cuda.manual_seed_all(seed)
    np.random.seed(seed)
    random.seed(seed)
    torch.backends.cudnn.benchmark = True
setup_seed(333)

env_path = os.path.join(os.path.dirname(__file__), '..')
if env_path not in sys.path:
    sys.path.append(env_path)

from pytracking.tracker.cas.cas import CAS
from utils.utils import get_axis_aligned_bbox, cxy_wh_2_rect

# Tracker initialisation
tracker = CAS('acnt_vot')
#tracker_vot = tracker_info.run_init()
handle = vot.VOT("polygon")
Polygon = handle.region()
cx, cy, w, h = get_axis_aligned_bbox(Polygon)
image_file = handle.frame()
if not image_file:
    sys.exit(0)

# Sequence initialisation (given first frame)
target_pos, target_sz = np.array([cx, cy]), np.array([w, h])
im = cv2.cvtColor(cv2.imread(image_file), cv2.COLOR_BGR2RGB)
tracker.run_vot_init(im, cxy_wh_2_rect(target_pos, target_sz))

while True:
    image_file = handle.frame()
    if not image_file:
        break
    im = cv2.cvtColor(cv2.imread(image_file), cv2.COLOR_BGR2RGB)

    state = tracker.track(im)  # track

    handle.report(Rectangle(state[0], state[1], state[2], state[3]))

